@@ -1,6 +1,5 @@
-# Copyright (c) 2016-2020 The Regents of the University of Michigan
-# This file is part of the General Simulation Data (GSD) project, released under
-# the BSD 2-Clause License.
+# Copyright (c) 2016-2021 The Regents of the University of Michigan
+# Part of GSD, released under the BSD 2-Clause License.
 
 """Test the gsd.fl API with large files."""
 
@@ -10,6 +9,7 @@ import pytest
 import gc
 
 
+@pytest.mark.validate
 @pytest.mark.parametrize("N", [2**27, 2**28, 2**29 + 1])
 def test_large_n(tmp_path, N):
     """Test data chunks and files larger than 2 GB."""
